@@ -119,7 +119,6 @@ g <- edit_plot(g,
                gp = gpar(fontface = "bold"))
 
 
-
 # Edit background of row 5
 g <- edit_plot(g, row = 5, which = "background",
                gp = gpar(fill = "darkolivegreen1"))
@@ -132,7 +131,10 @@ g <- insert_text(g,
                  gp = gpar(fontface = "bold"))
 
 # Add underline at the bottom of the header
-g <- add_underline(g, part = "header")
+g <- add_border(g, part = "header", row = 1, where = "top")
+g <- add_border(g, part = "header", row = 2, where = "bottom")
+g <- add_border(g, part = "header", row = 1, col = 2:3, 
+                gp = gpar(lwd = 2))
 
 
 # Insert text
@@ -141,7 +143,8 @@ g <- insert_text(g,
                  row = 10,
                  just = "left",
                  gp = gpar(cex = 0.6, col = "green", fontface = "italic"))
-
+# Add border
+g <- add_border(g, row = 10, col = 1:3, where = "top")
 plot(g)
 
 
